@@ -41,7 +41,7 @@ def print_stack():
     traceback.print_tb(e[2])
 
 class TheAlot(irc.bot.SingleServerIRCBot):
-    """A modular single-chanel IRC bot."""
+    """A modular single-channel IRC bot."""
     def __init__(self, config='config.json'):
         """Create and configure a new instance of the bot.
 
@@ -61,8 +61,8 @@ class TheAlot(irc.bot.SingleServerIRCBot):
 
         irc.bot.SingleServerIRCBot.__init__(self, 
             [(self.config['server'], self.config['port'])],
-            self.config['nickname'],
-            self.config['nickname']
+            self.config['nickname'], self.config['nickname'],
+            reconnection_interval = self.config['reconnection_interval']
         )
 
         self.connection.buffer_class.errors = 'replace' # Stop clients with latin-1 from crashing the bot
@@ -82,6 +82,29 @@ class TheAlot(irc.bot.SingleServerIRCBot):
         except:
             pass
 
+    def _on_disconnect(self, c, e):
+        """
+        Attempt to to reconnect to the server in case of a disconnect.
+        """
+        print(type(c), type(e))
+        print("Lost connection to the server, reconnecting in {} seconds...".format(self.reconnection_interval))
+        irc.bot.SingleServerIRCBot._on_disconnect(self, c, e)
+
+    def _connect(self):
+        """
+        Establish a connection to the server at the front of the server_list.
+        """
+        server = self.server_list[0]
+        print("Trying to connect to {}:{}...".format(server.host, server.port))
+        try:
+            self.connect(server.host, server.port, self._nickname,
+                server.password, ircname=self._realname)
+            print("Connected")
+        except irc.client.ServerConnectionError:
+            print("Connection timed out, retrying in {} seconds...".format(self.reconnection_interval))
+            self.connection.execute_delayed(self.reconnection_interval,
+                                            self._connected_checker)
+
     def hookEvent(self, eventType, method):
         """Add an event hook.
 
@@ -140,7 +163,6 @@ class TheAlot(irc.bot.SingleServerIRCBot):
             self.unloadPlugin(plugin=plugin)
 
         try:
-            print(plugin)
             name = to_camel_case(plugin) + "Plugin"
             module = __import__("thealot.plugins."+plugin, fromlist=[name])
             module = reload(module)
@@ -175,22 +197,21 @@ class TheAlot(irc.bot.SingleServerIRCBot):
 
         """
         if not cmd:
-            self.connection.notice(source, "Usage: help <command>")
+            self.connection.notice(source.nick, "Usage: help <command>")
         elif cmd in self.help:
             for subcmd in self.help[cmd]:
                 # dynamically adjust for the longest key in help
-                self.connection.notice(source, "{:<30} {}".format(subcmd, self.help[cmd][subcmd]))
+                self.connection.notice(source.nick, "{:<30} {}".format(subcmd, self.help[cmd][subcmd]))
         else:
-            self.connection.notice(source, "No help for that command")
+            self.connection.notice(source.nick, "No help for that command")
 
     def listCommands(self, source=None, target=None, args=None):
         """Display a list of all currently active commands."""
         for cmd in self.commands:
-            self.connection.notice(source, cmd)
+            self.connection.notice(source.nick, cmd)
 
     def saveConfig(self, source=None, args=None):
         """Save the configuration to a file."""
-        print(self.config)
         fh = open(self.configFile, "w")
         fh.write(json.dumps(self.config, indent=" "*4))
         fh.close()
@@ -218,7 +239,7 @@ class TheAlot(irc.bot.SingleServerIRCBot):
                 print_stack()
 
     def on_welcome(self, c, e):
-        """Override the method to call the \"welcome\" hooks.
+        """Override the method to call the "welcome" hooks.
 
         Arguments:
         c --
@@ -255,7 +276,7 @@ class TheAlot(irc.bot.SingleServerIRCBot):
                 except:
                     print_stack()
             else:
-               self.connection.privmsg(source, "Invalid Command")
+               self.connection.notice(source.nick, "Invalid Command")
 
 def main():
     # TODO allow passing config path as argument
